@@ -9,8 +9,8 @@ import enum
 import os
 import signal
 import sys
-import tomllib
 import typing
+import tomllib
 
 
 class Argparser:  # pylint: disable=too-few-public-methods
@@ -357,7 +357,6 @@ class TunnelManager:
                 self.data_cols[task_name]["status"] = "DOWN"
 
             del self.tunnel_test_tasks[task_name]
-            # return stdout, stderr
         except asyncio.TimeoutError:
             self.write_log(f"test for {task_name} timed out\n")
             self.data_cols[task_name]["status"] = "TMOUT"
@@ -396,8 +395,7 @@ class TunnelManager:
                 )
                 await asyncio.sleep(0)
                 self.data_cols[k] = copy.deepcopy(value)
-                if k in self.scheduler_table:
-                    self.scheduler_table[k] = 0
+                self.scheduler_table[k] = 0
             else:
                 if (
                     self.data_cols[k]["command"] != data_cols_new[k]["command"]
@@ -492,6 +490,9 @@ class TunnelManager:
                 await self.stop_task(task, self.tunnel_tasks)
                 was_active = True
                 self.data_cols[name]["disabled"] = "manual"
+                if name in self.tunnel_test_tasks:
+                    self.tunnel_test_tasks[name].cancel()
+                await asyncio.sleep(0)
                 break
 
         if not was_active:
@@ -505,6 +506,11 @@ class TunnelManager:
             self.data_cols[name]["disabled"] = ""
             await asyncio.sleep(0)
 
+    def run_single_test(self, task_name):
+        """Set the counter to 0 so the scheduler will run the test"""
+        if task_name in self.scheduler_table:
+            self.scheduler_table[task_name] = 0
+
     async def quit(self) -> None:
         """Cleanly quit the applicaiton"""
         # scheduler checks for this to stop running new tests
@@ -610,6 +616,9 @@ class TunnelManager:
                 elif char == ord("r"):
                     line_content = self.stdscr.instr(sel + 2, 1)
                     await self.restart_task(line_content.decode("utf-8"))
+                elif char == ord("t"):
+                    line_content = self.stdscr.instr(sel + 2, 1)
+                    await self.run_single_test(line_content.decode("utf-8"))
                 elif char == ord("q"):
                     await self.quit()
                 elif char == ord("s"):
